.. role:: hidden
    :class: hidden-section

ax.runners
==========

.. automodule:: ax.runners
.. currentmodule:: ax.runners

BoTorch Test Problem
~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.runners.botorch_test_problem
    :members:
    :undoc-members:
    :show-inheritance:

SingleRunningTrialMixin
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.runners.single_running_trial_mixin
    :members:
    :undoc-members:
    :show-inheritance:

Synthetic Runner
~~~~~~~~~~~~~~~~

.. automodule:: ax.runners.synthetic
    :members:
    :undoc-members:
    :show-inheritance:

Simulated Backend Runner
~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.runners.simulated_backend
    :members:
    :undoc-members:
    :show-inheritance:

TorchX Runner
~~~~~~~~~~~~~

.. automodule:: ax.runners.torchx
    :members:
    :undoc-members:
    :show-inheritance:
